@@ -485,7 +485,7 @@ class NodeList {
 	public static void replace(final IReplaceInputInformation info, final String searchString,
 	                           final String replaceString) {
 		final String regExp = "(" + NodeList.getPureRegularExpression(searchString) + ")";
-		Pattern p;
+		final Pattern p;
 		try {
 			p = Pattern.compile(regExp, Pattern.CASE_INSENSITIVE);
 		}
@@ -493,6 +493,9 @@ class NodeList {
 			UITools.errorMessage(FpStringUtils.format("wrong_regexp", searchString, e.getMessage()));
 			return;
 		}
+		if(p.matcher("").matches()){
+			return;
+		}
 		final String replacement = NodeList.getPureRegularExpression(replaceString);
 		final int length = info.getLength();
 		for (int i = 0; i < length; i++) {
@@ -511,12 +514,8 @@ class NodeList {
 		}
 	}
 
-	private static String replace(final Pattern p, final String replacement, String replaceResult) {
-		Object before;
-		do {
-			before = replaceResult;
-			replaceResult = HtmlTools.getInstance().getReplaceResult(p, replacement, replaceResult);
-		} while (!replaceResult.equals(before));
+	private static String replace(final Pattern p, final String replacement, String input) {
+		String replaceResult = HtmlTools.getReplaceResult(p, replacement, input);
 		return replaceResult;
 	}
 
