@@ -346,6 +346,9 @@ public class XMLElement implements Serializable {
 	 * @return the attribute, or null if the attribute does not exist.
 	 */
 	private XMLAttribute findAttribute(final String fullName) {
+		if (fullName == null) {
+			throw new IllegalArgumentException("fullName must not be null");
+		}
 		final Enumeration enumeration = attributes.elements();
 		while (enumeration.hasMoreElements()) {
 			final XMLAttribute attr = (XMLAttribute) enumeration.nextElement();
@@ -366,6 +369,9 @@ public class XMLElement implements Serializable {
 	 * @return the attribute, or null if the attribute does not exist.
 	 */
 	private XMLAttribute findAttribute(final String name, final String namespace) {
+		if (name == null) {
+			throw new IllegalArgumentException("name must not be null");
+		}
 		final Enumeration enumeration = attributes.elements();
 		while (enumeration.hasMoreElements()) {
 			final XMLAttribute attr = (XMLAttribute) enumeration.nextElement();
@@ -832,6 +838,9 @@ public class XMLElement implements Serializable {
 	 *            the non-null name of the attribute.
 	 */
 	public void removeAttribute(final String name) {
+		if (name == null) {
+			throw new IllegalArgumentException("name must not be null");
+		}
 		for (int i = 0; i < attributes.size(); i++) {
 			final XMLAttribute attr = (XMLAttribute) attributes.elementAt(i);
 			if (attr.getFullName().equals(name)) {
@@ -850,6 +859,9 @@ public class XMLElement implements Serializable {
 	 *            the namespace URI of the attribute, which may be null.
 	 */
 	public void removeAttribute(final String name, final String namespace) {
+		if (name == null) {
+			throw new IllegalArgumentException("name must not be null");
+		}
 		for (int i = 0; i < attributes.size(); i++) {
 			final XMLAttribute attr = (XMLAttribute) attributes.elementAt(i);
 			boolean found = attr.getName().equals(name);
@@ -898,6 +910,9 @@ public class XMLElement implements Serializable {
 	 *            the non-null value of the attribute.
 	 */
 	public void setAttribute(final String name, final String value) {
+		if (value == null) {
+			throw new IllegalArgumentException("value must not be null");
+		}
 		XMLAttribute attr = this.findAttribute(name);
 		if (attr == null) {
 			attr = new XMLAttribute(name, name, null, value, "CDATA");
@@ -919,6 +934,12 @@ public class XMLElement implements Serializable {
 	 *            the non-null value of the attribute.
 	 */
 	public void setAttribute(final String fullName, final String namespace, final String value) {
+		if (fullName == null) {
+			throw new IllegalArgumentException("fullName must not be null");
+		}
+		if (value == null) {
+			throw new IllegalArgumentException("value must not be null");
+		}
 		final int index = fullName.indexOf(':');
 		final String name = fullName.substring(index + 1);
 		XMLAttribute attr = this.findAttribute(name, namespace);
@@ -950,6 +971,9 @@ public class XMLElement implements Serializable {
 	 *            the non-null name.
 	 */
 	public void setName(final String name) {
+		if (name == null) {
+			throw new IllegalArgumentException("name must not be null");
+		}
 		this.name = name;
 		fullName = name;
 		namespace = null;
@@ -964,6 +988,9 @@ public class XMLElement implements Serializable {
 	 *            the namespace URI, which may be null.
 	 */
 	public void setName(final String fullName, final String namespace) {
+		if (fullName == null) {
+			throw new IllegalArgumentException("fullName must not be null");
+		}
 		final int index = fullName.indexOf(':');
 		if ((namespace == null) || (index < 0)) {
 			name = fullName;
